// Copyright 2016, University of Colorado Boulder

/**
 *  This function creates a content string for common/generateReport.js
 *
 *  @author Matt Pennington
 *  @author Michael Kauzmann
 */

(function() {
  'use strict';

  function createHeader( num, text ) {
    var header = document.createElement( 'h' + num );
    header.innerHTML = text;
    return header;
  }

  function createLabeledText( label, text ) {
    var p = document.createElement( 'p' );

    var labelSpan = document.createElement( 'span' );
    labelSpan.classList.add( 'labelSpan' );
    labelSpan.innerHTML = label + ':';
    p.appendChild( labelSpan );

    p.innerHTML += ' ';

    var textSpan = document.createElement( 'span' );
    textSpan.classList.add( 'text' );
    textSpan.innerHTML = text;
    p.appendChild( textSpan );

    return p;
  }

  function getPredictionText( val ) {
    if ( val === 'red' ) {
      return 'Red team wins.';
    }
    else if ( val === 'blue' ) {
      return 'Blue team wins.';
    }
    else if ( val === 'tie' ) {
      return 'Cart doesn\'t move';
    }
    else {
      return 'ERROR: NO PREDICTION';
    }
  }

  /**
   * This creates an html report of the user input for the classroom-activity wrapper.
   * @returns {Element}
   */
  window.drawReport = function() {

    var content = document.createElement( 'html' );

    var style = document.createElement( 'style' );
    style.innerHTML = '#phet-data-table-experiment-table tbody { max-height: none; }';
    style.innerHTML += '.phet-data-table .fa-play-circle:hover { color: cornflowerblue; cursor: default; }';
    content.appendChild( style );

    // identifier
    content.appendChild( createHeader( 1, 'Name:') );
    content.appendChild( document.createElement('textarea') );

    // predict tab
    content.appendChild( createHeader( 1, 'Predict Tab:' ) );
    content.appendChild( createLabeledText( 'Prediction', getPredictionText( window.classroom.predict.prediction ) ) );
    content.appendChild( createLabeledText( 'Reason for prediction', window.classroom.predict.explanation ) );

    // explore tab
    content.appendChild( createHeader( 1, 'Explore Tab:' ) );
    content.appendChild( createLabeledText( 'Observations', window.classroom.explore.notes ) );

    // experiment tab
    content.appendChild( createHeader( 1, 'Experiment Tab:' ) );
    window.classroom.experiment.ideas.forEach( function( ideaValue, idx ) {
      var index = idx + 1;
      content.appendChild( createLabeledText( 'Idea ' + index, ideaValue.idea ) );
      content.appendChild( createLabeledText( 'What I learned', ideaValue.summary ) );
      var tableDiv = document.createElement( 'div' );
      ideaValue.dataTable.drawTable( tableDiv );
      content.appendChild( tableDiv );
    } );

    //reflect tab
    content.appendChild( createHeader( 1, 'Reflect Tab:' ) );
    content.appendChild( createLabeledText( 'Rules', window.classroom.reflect.rules ) );
    var tableDiv = document.createElement( 'div' );
    window.classroom.reflect.dataTable.drawTable( tableDiv );
    content.appendChild( tableDiv );

    // apply tab
    content.appendChild( createHeader( 1, 'Apply Tab:' ) );
    window.classroom.apply.cases.forEach( function( caseValue, idx ) {
      var index = idx + 1;
      content.appendChild( createHeader( 2, 'Case ' + index + ':' ) );
      content.appendChild( createLabeledText( 'Prediction', getPredictionText( caseValue.prediction ) ) );
      content.appendChild( createLabeledText( 'Explanation', caseValue.explanation ) );
    } );
    content.appendChild( createLabeledText( 'Edited rules', window.classroom.apply.rules ) );

    return content;
  };
})();