// Copyright 2016, University of Colorado Boulder

/**
 * This function takes a body element, adds a PhET-iO template, and opens it in a new window/tab.
 * @author - Matt Pennington
 * @author - Michael Kauzmann
 *
 * @param content - DOM element to add to template
 * @param css - [filename] - list of filename
 * @param title - {string} to be inserted into the document title for the report
 */
(function() {
  'use strict';

  function getCSS() {
    var cssText = '';
    var i;
    var j;
    for ( i = 0; i < document.styleSheets.length; i++ ) {
      if ( document.styleSheets[ i ].cssRules ) {
        for ( j = 0; j < document.styleSheets[ i ].cssRules.length; j++ ) {
          cssText += document.styleSheets[ i ].cssRules[ j ].cssText;
        }
      }
      else if ( document.styleSheets[ i ].rules ) {
        for ( j = 0; j < document.styleSheets[ i ].rules.length; j++ ) {
          cssText += document.styleSheets[ i ].rules[ j ].cssText;
        }
      }
    }
    return cssText;
  }

  /**
   * Async loads a template.
   * Generates the report from the content and title given.
   * @param content
   * @param title
   * @callback cb
   * @returns {String} - a string of the HTML generated for the popup, this is handy for recording to the event stream
   */
  window.generateReport = function( content, title, cb ) {
    var request = new XMLHttpRequest();
    request.addEventListener( 'load', function() {
      var html = request.responseText;
      html = html.replace( '{{CONTENT}}', content.innerHTML );
      html = html.replace( '{{DOCTITLE}}', title );
      html = html.replace( '{{DESCRIPTION}}', title );
      html = html.replace( '{{CSS_TEXT}}', getCSS() );


      var popup = window.open();
      if ( !popup ) {
        window.alert( 'Popup was blocked, please allow popups to launch the customized simulation.' );
      }
      else {
        popup.document.write( html );
        cb(html);
      }
    } );
    request.open( 'GET', '../common/html/generateHtmlReportTemplate.html', true );
    request.send( null );
  };
})();
