// Copyright 2017, University of Colorado Boulder

/**
 * @author - Sam Reid (PhET Interactive Simulations)
 * @author - Michael Kauzmann (PhET Interactive Simulations)
 */
(function() {
  'use strict';

  /**
   * Fill in the appropriate query parameters for each sim link
   * @param sim
   * @param suffix
   */
  var patchLinks = function( sim, suffix ) {
    var a = document.getElementsByClassName( 'sim-link' );
    for ( var i = 0; i < a.length; i++ ) {
      var elm = a[ i ];

      var console = elm.href.indexOf( '/record/record.html' ) >= 0 ? '&console' : '';
      elm.href = elm.href + '?sim=' + sim + suffix + console;
    }
  };

  if ( WrapperUtils.isBuilt ) {

    // Look up the name of the sim from the pathname.  For example:
    // faradays-law/build/wrappers/index
    // faradays-law/1.2.0-phetiorc.1/wrappers/index/index.html
    // Supports /index and /index/index.html
    var path = window.location.pathname.split( '/' );
    var simulation = path[ path.length - 5 ];

    var linkToSimulation = '../../' + simulation + '_en-phetio.html?phetioStandalone';
    document.getElementById( 'colorized' ).href = linkToSimulation + '&phetioLog=lines';
    document.getElementById( 'json' ).href = linkToSimulation + '&phetioLog=console';
    document.getElementById( 'simulation' ).href = linkToSimulation;

    // On spot, automatically append relativeSimPath so the getSim() calls will use relative paths
    // since the phet-io main version is not published yet
    var suffix = '';
    if ( window.location.hostname === 'www.colorado.edu' || window.location.pathname.indexOf( 'build/' ) >= 0 ) {
      suffix = '&relativeSimPath';
    }
    patchLinks( simulation, suffix );
  }

  // Requirejs mode
  else {
    // phet-io-wrappers/index/
    // The "sim" query parameter is required for requirejs mode.
    var sim = QueryStringMachine.get( 'sim', { type: 'string' } );

    var linkToRequirejsSim = '../../' + sim + '/' + sim + '_en.html?brand=phet-io&phetioStandalone';
    document.getElementById( 'colorized' ).href = linkToRequirejsSim + '&phetioLog=lines';
    document.getElementById( 'json' ).href = linkToRequirejsSim + '&phetioLog=console';
    document.getElementById( 'simulation' ).href = linkToRequirejsSim;

    patchLinks( sim, '' );

    var requireJSPath = window.location.pathname.split( 'index.html' )[ 0 ];
    document.getElementById( 'devguide' ).href = requireJSPath + '../../phet-io-website/root/devguide/';
  }


  // Toggle the phetioValidateTandems query parameter in conjunction with the checkbox on the page.
  // NOTE: this listener assumes that it is the final query parameter to toggle, that is why it is in a separate script.
  document.addEventListener( 'DOMContentLoaded', function() {

    // Only create this checkbox if turned on with a query parameter
    var toggleValidateTandems = QueryStringMachine.get( 'toggleValidateTandems', { type: 'flag' } );
    if ( toggleValidateTandems ) {

      var validateCheckbox = document.createElement( 'input' );
      validateCheckbox.type = 'checkbox';
      validateCheckbox.name = 'name';
      validateCheckbox.id = 'validateTandemsCheckbox';

      var validateCheckboxLabel = document.createElement( 'label' );
      validateCheckboxLabel.htmlFor = 'validateTandemsCheckbox';
      validateCheckboxLabel.appendChild( document.createTextNode( 'Validate Tandems' ) );


      validateCheckbox.addEventListener( 'change', function( event ) {
        var validate = event.target.checked; // will be true if checked

        var links = document.querySelectorAll( '.link' );
        for ( var i = 0; i < links.length; i++ ) {
          var aTag = links[ i ];

          if ( validate ) {
            aTag.href = aTag.href.split( '&phetioValidateTandems=false' )[ 0 ] + '&phetioValidateTandems=true';
          }
          else {
            aTag.href = aTag.href.split( '&phetioValidateTandems=true' )[ 0 ] + '&phetioValidateTandems=false';
          }
        }
      } );

      // Append the newly created checkbox and label
      document.getElementsByClassName( 'content' )[ 0 ].appendChild( validateCheckbox );
      document.getElementsByClassName( 'content' )[ 0 ].appendChild( validateCheckboxLabel );

      // Click it to activate the above query parameters (always enabled to start)
      validateCheckbox.click();
    }
  } );
})();