// Copyright 2016, University of Colorado Boulder

/**
 * This validator accepts a default of 999 user ids.
 * The numberOfIDs query parameter of will overwrite 999
 *
 * Each starts with [prefix]
 *
 * Each end part increments the number and letter by one
 * so [prefix]26z will increment to[prefix]27a
 *
 * Some examples:
 * [prefix]1a
 * [prefix]2b
 * ...
 * [prefix]100v (the hundredth id)
 * ...
 * [prefix]999k (the 999th id) The last legal default id
 *
 * TO TEST:
 * use: phettest
 *
 * @author Michael Kauzmann (PhET Interactive Simulations)
 * @author Sam Reid (PhET Interactive Simulations)
 *
 * @param loginID string inputted on login
 * @returns {{error: null}|string} Object containing value error, which contains a message if the validation was not successful and is null otherwise
 */
window.validationRule = function( loginID ) {
  'use strict';

  var queryParameters = QueryStringMachine.getAll( {
    'validationPrefix': {
      type: 'string'
    },
    'numberOfIDs': {
      type: 'number',
      defaultValue: 999
    }
  } );

  // The prefix appended to each id
  var prefix = queryParameters.validationPrefix;
  // The total number of ids generated
  var NUMBER_OF_IDS = queryParameters.numberOfIDs;

  var all = [];
  for ( var i = 1; i <= NUMBER_OF_IDS; i++ ) {
    var id = prefix;
    id = id + i;

    // Append the correct ordered letter to the end
    id = id + String.fromCharCode( 97 + (i - 1 ) % 26 );
    all.push( id );
  }
  /**
   *  Add a testing id for all validation rules: phettest
   */
  all.push( 'phettest' );

  if ( all.indexOf( loginID ) >= 0 ) {
    return { error: null };
  }
  return { error: 'Error: id not found' };
};

