// Copyright 2016, University of Colorado Boulder

/**
 * This script provides recording facilities, outputting data to metacog, the console, or a localFile.  See Recorder.js for
 * a list of dependencies.
 *
 * @author Sam Reid (PhET Interactive Simulations)
 */
(function() {
  'use strict';

  // Load the simulation
  var sim = WrapperUtils.getSim( 'john-travoltage', '1.4.0-phetiodev.1' );
  var simFrame = document.getElementById( 'sim' );
  var simIFrameClient = new SimIFrameClient( simFrame );

  var recordInputEvents = QueryStringMachine.get( 'phetioEmitInputEvents', { type: 'boolean', defaultValue: true } );
  console.log( 'phetioEmitInputEvents = ' + recordInputEvents );

  // Initialize the Recording module, which will check query parameters and prepare for data recording.
  var recorder = new window.Recorder();

  // When the recorder is ready, launch the sim.
  recorder.start( function( sessionMetadata ) {
    simIFrameClient.launchSim( sim.URL, {
      emitInputEvents: recordInputEvents,
      phetioEventsListener: function( message ) {

        // Send the data
        recorder.recordMessage( message );
      },
      simStartedMetadata: sessionMetadata
    } );
  } );
})();